@@ -1,3 +1,6 @@
+from core_main_app.utils.databases.mongoengine_database import Database
+import os
+
 SECRET_KEY = "fake-key"
 
 INSTALLED_APPS = [
@@ -35,4 +38,30 @@ TEMPLATES = [
     },
 ]
 
+# IN-MEMORY TEST DATABASE
+DATABASES = {
+    "default": {
+        "ENGINE": "django.db.backends.sqlite3",
+        "NAME": ":memory:",
+        "USER": "",
+        "PASSWORD": "",
+        "HOST": "",
+        "PORT": "",
+    },
+}
+MOCK_DATABASE_NAME = "db_mock"
+MOCK_DATABASE_HOST = "mongomock://localhost"
+
 CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT = False
+
+database = Database(MOCK_DATABASE_HOST, MOCK_DATABASE_NAME)
+database.connect()
+
+
+AUTO_SET_PID = os.getenv("AUTO_SET_PID", "False").lower() == "true"
+""" boolean: enable SAML2 SSO authentication.
+"""
+
+# Update Django Settings
+if AUTO_SET_PID:
+    INSTALLED_APPS = INSTALLED_APPS + ("core_linked_records_app",)
